@@ -79,7 +79,8 @@ class ContextBuilder:
 
     @staticmethod
     def chain_of_thought_prompt(agent: ChattyAIAgent, mode_in_chat: ChattyAIMode, trigger: ChainOfThoughtInChatTrigger) -> str:
-        context = f"\n\nRemember that {mode_in_chat.value} mode."
+        context = f"\n\nRemember that you are in {mode_in_chat.value} mode."
         context += f"Remember to follow each unbreakable rule:\n- {'\n- '.join(agent.unbreakable_rules)}"
         context += f"\n\n{ContextBuilder.chain_of_thought_instructions_and_final_prompt(trigger)}"
-        return context
\ No newline at end of file
+        return context
+
