@@ -26,7 +26,7 @@ from ...models.chat.scheduled_messages import ScheduledMessageStatus
 from ...models.utils.types.identifier import StrObjectId
 from ...models.utils.custom_exceptions.custom_exceptions import AssetAlreadyAssigned, MessageNotFoundError, NotFoundError, MessageAlreadyInChat, MetaErrorNotification, ChatAlreadyAssigned, AlreadyCompleted, ErrorToMantainSafety
 from ..factories.messages.central_notification_factory import CentralNotificationFactory
-from ...models.messages.chatty_messages.base.message_draft import MessageDraft
+from ...models.messages.chatty_messages.base.message_draft import ChattyContentAudio, MessageDraft
 from ...models.messages.chatty_messages.schema.chatty_content.content_central import CentralNotificationStatus
 from ...models.messages.chatty_messages.schema import ChattyContext
 from ...models.utils.types.message_types import MessageType
@@ -706,4 +706,19 @@ class ChatService:
         chat.suggested_messages = []
         logger.debug(f"Removed all suggested messages from chat {chat.id} #{chat.client.get_waid()}")
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        return chat
+
+    @staticmethod
+    def add_audio_transcription(chat: Chat, transcript:str, message_id:StrObjectId, execution_context:ExecutionContext) -> Chat:
+        """
+        Add an audio transcription to the chat.
+        """
+        message = chat.get_message_by_id(message_id)
+        if message is None:
+            raise MessageNotFoundError(message=f"Message with id {message_id} not found in chat {chat.id}")
+        if not isinstance(message.content, ChattyContentAudio):
+            raise ValueError(f"Message with id {message_id} is not an audio message")
+        message.content.transcription = transcript
+        logger.debug(f"Added audio transcription to chat {chat.id} #{chat.client.get_waid()}")
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
         return chat
\ No newline at end of file
